==> zio-aws-schemas_2.13-5.17.129.2-sources.jar: zio/aws/schemas/model/ListSchemasRequest.scala <==
package zio.aws.schemas.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.schemas.model.primitives.{__string, __integer}
import scala.jdk.CollectionConverters._
final case class ListSchemasRequest(
    limit: Option[__integer] = None,
    nextToken: Option[__string] = None,
    registryName: __string,
    schemaNamePrefix: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.ListSchemasRequest = {
    import ListSchemasRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.ListSchemasRequest
      .builder()
      .optionallyWith(limit.map(value => __integer.unwrap(value): Integer))(
        _.limit
      )
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .registryName(__string.unwrap(registryName): java.lang.String)
      .optionallyWith(
        schemaNamePrefix.map(value => __string.unwrap(value): java.lang.String)
      )(_.schemaNamePrefix)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.ListSchemasRequest.ReadOnly =
    zio.aws.schemas.model.ListSchemasRequest.wrap(buildAwsValue())
}
object ListSchemasRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.ListSchemasRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.ListSchemasRequest =
      zio.aws.schemas.model.ListSchemasRequest(
        limit.map(value => value),
        nextToken.map(value => value),
        registryName,
        schemaNamePrefix.map(value => value)
      )
    def limit: Option[__integer]
    def nextToken: Option[__string]
    def registryName: __string
    def schemaNamePrefix: Option[__string]
    def getLimit: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getRegistryName: ZIO[Any, Nothing, __string] = ZIO.succeed(registryName)
    def getSchemaNamePrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("schemaNamePrefix", schemaNamePrefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.ListSchemasRequest
  ) extends zio.aws.schemas.model.ListSchemasRequest.ReadOnly {
    override val limit: Option[__integer] = scala
      .Option(impl.limit())
      .map(value => zio.aws.schemas.model.primitives.__integer(value))
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.schemas.model.primitives.__string(value))
    override val registryName: __string =
      zio.aws.schemas.model.primitives.__string(impl.registryName())
    override val schemaNamePrefix: Option[__string] = scala
      .Option(impl.schemaNamePrefix())
      .map(value => zio.aws.schemas.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.ListSchemasRequest
  ): zio.aws.schemas.model.ListSchemasRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-schemas_2.13-5.17.158.4-sources.jar: zio/aws/schemas/model/ListSchemasRequest.scala <==
package zio.aws.schemas.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.schemas.model.primitives.{__string, __integer}
import scala.jdk.CollectionConverters._
final case class ListSchemasRequest(
    limit: Option[__integer] = None,
    nextToken: Option[__string] = None,
    registryName: __string,
    schemaNamePrefix: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.ListSchemasRequest = {
    import ListSchemasRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.ListSchemasRequest
      .builder()
      .optionallyWith(limit.map(value => value: Integer))(_.limit)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .registryName(registryName: java.lang.String)
      .optionallyWith(schemaNamePrefix.map(value => value: java.lang.String))(
        _.schemaNamePrefix
      )
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.ListSchemasRequest.ReadOnly =
    zio.aws.schemas.model.ListSchemasRequest.wrap(buildAwsValue())
}
object ListSchemasRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.ListSchemasRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.ListSchemasRequest =
      zio.aws.schemas.model.ListSchemasRequest(
        limit.map(value => value),
        nextToken.map(value => value),
        registryName,
        schemaNamePrefix.map(value => value)
      )
    def limit: Option[__integer]
    def nextToken: Option[__string]
    def registryName: __string
    def schemaNamePrefix: Option[__string]
    def getLimit: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getRegistryName: ZIO[Any, Nothing, __string] = ZIO.succeed(registryName)
    def getSchemaNamePrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("schemaNamePrefix", schemaNamePrefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.ListSchemasRequest
  ) extends zio.aws.schemas.model.ListSchemasRequest.ReadOnly {
    override val limit: Option[__integer] =
      scala.Option(impl.limit()).map(value => value: __integer)
    override val nextToken: Option[__string] =
      scala.Option(impl.nextToken()).map(value => value: __string)
    override val registryName: __string = impl.registryName(): __string
    override val schemaNamePrefix: Option[__string] =
      scala.Option(impl.schemaNamePrefix()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.ListSchemasRequest
  ): zio.aws.schemas.model.ListSchemasRequest.ReadOnly = new Wrapper(impl)
}
